@@ -5,14 +5,15 @@ import munch
 @pytest.fixture(name='yaml')
 def yaml_module():
     try:
-        import yaml
+        import yaml  # pylint: disable=import-outside-toplevel
         return yaml
     except ImportError:
         pass
     pytest.skip("Module 'PyYAML' is required")
 
 
-@pytest.fixture(params=[munch.Munch, munch.AutoMunch, munch.DefaultMunch, munch.DefaultFactoryMunch])
+@pytest.fixture(params=[munch.Munch, munch.AutoMunch, munch.DefaultMunch, munch.DefaultFactoryMunch,
+                        munch.RecursiveMunch])
 def munch_obj(request):
     cls = request.param
     args = tuple()
